<?php

declare(strict_types=1);

namespace Drupal\commerce_order_item_ui\EventSubscriber;

use Drupal\commerce_order\Event\OrderItemEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Order Item events subscriber.
 */
class OrderItemSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      'commerce_order.commerce_order_item.insert' => ['onOrderItemInsert'],
      'commerce_order.commerce_order_item.update' => ['onOrderItemInsert'],
      'commerce_order.commerce_order_item.delete' => ['onOrderItemDelete'],
    ];
  }

  /**
   * Force order update when order item is updated.
   *
   * @param \Drupal\commerce_order\Event\OrderItemEvent $order_item_event
   *   Order item event.
   */
  public function onOrderItemInsert(OrderItemEvent $order_item_event): void {
    $order_item = $order_item_event->getOrderItem();
    $order = $order_item->getOrder();

    // Ensure there's a reference on the parent order.
    if ($order && !$order->hasItem($order_item)) {
      $order->addItem($order_item);
      $order->save();
    }
  }

  /**
   * Force order update when order item is updated.
   *
   * @param \Drupal\commerce_order\Event\OrderItemEvent $order_item_event
   *   Order item event.
   */
  public function onOrderItemDelete(OrderItemEvent $order_item_event): void {
    $order_item = $order_item_event->getOrderItem();
    $order = $order_item->getOrder();

    // Remove the reference from the parent order.
    if ($order && $order->hasItem($order_item)) {
      $order->removeItem($order_item);
      $order->save();
    }
  }

}
